# Marlin

Swim between bookmarks in the terminal!

[![Build Status](https://travis-ci.org/wilfredinni/marlin.svg?branch=master)](https://travis-ci.org/wilfredinni/marlin) [![BCH compliance](https://bettercodehub.com/edge/badge/wilfredinni/marlin?branch=master)](https://bettercodehub.com/) [![Codacy Badge](https://api.codacy.com/project/badge/Grade/d70f49cf01014dcaa6afc78a94fc16d5)](https://www.codacy.com/app/carlos.w.montecinos/marlin?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=wilfredinni/marlin&amp;utm_campaign=Badge_Grade) [![Requirements Status](https://requires.io/github/wilfredinni/marlin/requirements.svg?branch=master)](https://requires.io/github/wilfredinni/marlin/requirements/?branch=master) [![license](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/wilfredinni/marlin/blob/master/LICENSE)

![marlin!](terminal.gif "marlin!")

Marlin is an easy to use bookmark manager for the terminal. Choose a folder, bookmark it and swim there whenever you want!
Because we too deserve to move fast in the terminal :triumph:!

## Usage

### Install

    pip install marlin-bookmark

### Bookmark

    bookmark [bookmark-name]

### Remove a Bookmark

    rmark [bookmark-name]

### List Bookmarks

    marlin

### Swim!

    marlin [bookmark-name]

## TODO

- command shortcuts (e.g. `$ git add .` to `marlin ga.`)
